==> haskell-text-latin1-0.3.1-241-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-latin1
version:              0.3.1
visibility:           public
id:                   text-latin1-0.3.1-JCu8faaq4FjCytO4p1sF7L
key:                  text-latin1-0.3.1-JCu8faaq4FjCytO4p1sF7L
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-latin1
synopsis:             Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.

category:             Text
abi:                  58443742db48c9a6b649ff1262421239
exposed:              True
exposed-modules:      Text.Ascii Text.Latin1
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-latin1
hs-libraries:         HStext-latin1-0.3.1-JCu8faaq4FjCytO4p1sF7L
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-LMolnZwpRvW7BfRj8XMS7A
    data-checked-0.3-2xOO5aVFI22KJDTvb8lvZD
    hashable-1.4.4.0-9MfualSpDNWnshBkTCGL2 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html:         /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-latin1-0.3.1-242-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-latin1
version:              0.3.1
visibility:           public
id:                   text-latin1-0.3.1-7TTFzp5GN3IISSCcyxPlVD
key:                  text-latin1-0.3.1-7TTFzp5GN3IISSCcyxPlVD
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-latin1
synopsis:             Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.

category:             Text
abi:                  a6a43481563f3d24c982b0dc036c6e1f
exposed:              True
exposed-modules:      Text.Ascii Text.Latin1
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-latin1
hs-libraries:         HStext-latin1-0.3.1-7TTFzp5GN3IISSCcyxPlVD
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-9695IAuXzI9BpRD3yNxY1D
    data-checked-0.3-2xOO5aVFI22KJDTvb8lvZD
    hashable-1.4.4.0-HA5jWeGkLE053htWZjUgjX text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html:         /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
